Examples
========

`sgidal-example <https://github.com/openEDI/sgidal-example>`_

- Power Flow: opendss simulation
- A measurement apparent
- State estimator algorithm
- Recorder federates
- Optimization algorithm in progress
